/***********

While Borland Custom Controls are meant for use in BorDlg and BorDlg_Gray
dialog boxes, some of them also work in a normal dialog.  As a control is a
window, it will send the same message to the parent dialog window as it would
send to a BWCC dialog.

This has a normal, Windows dialog box.  A partially grayed bitmap is used to
paint the background instead of letting the dialog box procedure do it (the
BWCC dialogs don't let you do this by the way).  A bitmapped button is placed
in the dialog and works the same as in a Borland dialog.

Buttons already provided by BWCC are also included to show what is avaialble.

Both Windows style and Borland style static text are placed into both dialogs
to show their difference in a Windows dialog.  Notice how the Bordlg window
procedure converts how the Windows static text is handled.

The background painting of the Windows dialog leaves a white area around the
Borland-style bitmapped buttons.  Both the Borland and the Windows dialog
boxes have a partially grayed background but the Borland static text style in
the Windows dialog and both static text styles in the Borland dialog have
even gray backgrounds so they don't match (Borland shade could help with this).
Changing the Borland dialog class name from "bordlg" to "bordlg_gray" will
change it to have the same background as that used in the static text. 

************/

#include <windows.h>
#include <bwcc.h>

#include "bwccdmo1.rh"

HWND main_hwnd;
BOOL modify_background;
char program_name[] = "BWCC Demo 1";

extern HINSTANCE _hInstance;

#pragma argsused
BOOL FAR PASCAL _export AboutDlgProc(HWND hDlg, WORD message,
                                     WORD wParam, LPARAM lParam)
  {
  RECT r;
  static HBITMAP brush_bitmap;
  static HBRUSH  back_brush;

  if (message == WM_INITDIALOG)
    {
    // load the bitmap that will be used as the background brush

    brush_bitmap = LoadBitmap(_hInstance, MAKEINTRESOURCE(BMP_BRUSH));

    // make up a brush from the bitmap

    back_brush = CreatePatternBrush(brush_bitmap);

    // return TRUE, indicating we've handled the message

    return TRUE;
    }
  else if (message == WM_ERASEBKGND)
    {
    if (!modify_background)
      return FALSE;

    // get the dimensions of the main window
    GetClientRect(hDlg, &r);

    // FillRect() stops 1 short in width and height, so adjust rectangle
    ++r.right;
    ++r.bottom;

    // Color the background
    FillRect((HDC) wParam, &r, back_brush);
    return TRUE;
    }
  else if (message == WM_COMMAND)
    {
    // wParam values received will be:
    // IDCANCEL if the user presses Escape or double clicks system menu box
    // ID_OK from the bitmapped Borland button

    if ((wParam == ID_OK) || (wParam == IDCANCEL))
      {
      // Free GDI objects and close the dialog

      if (back_brush)
        DeleteObject(back_brush);

      if (brush_bitmap)
        DeleteObject(brush_bitmap);

      EndDialog(hDlg, 0);
      return TRUE;
      }
    }

  return FALSE;
  }



LRESULT CALLBACK _export WndProc(HWND hwnd, UINT message,
                                      WPARAM wParam, LPARAM lParam)
  {
  PAINTSTRUCT ps;
  static FARPROC dialog_procinstance;

  if (message == WM_PAINT)
    {
    if (!dialog_procinstance)
      {
      dialog_procinstance =
        MakeProcInstance((FARPROC) AboutDlgProc, _hInstance);
      DialogBox(_hInstance, MAKEINTRESOURCE(NORMAL_DIALOG),
                main_hwnd, (DLGPROC) dialog_procinstance);

      modify_background = TRUE;
      DialogBox(_hInstance, MAKEINTRESOURCE(MODIFIED_WINDOWS_DIALOG),
                main_hwnd, (DLGPROC) dialog_procinstance);

      modify_background = FALSE;
      DialogBox(_hInstance, MAKEINTRESOURCE(BWCC_DIALOG),
                main_hwnd, (DLGPROC) dialog_procinstance);
      DialogBox(_hInstance, MAKEINTRESOURCE(BWCC_GRAY_DIALOG),
                main_hwnd, (DLGPROC) dialog_procinstance);
      FreeProcInstance(dialog_procinstance);
      PostQuitMessage(0);
      }

    BeginPaint(hwnd, &ps);
    EndPaint(hwnd, &ps);
    return 0;
    }

  return DefWindowProc(hwnd, message, wParam, lParam);
  }



#pragma argsused
int PASCAL WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
                   LPSTR command_line,  int nCmdShow)
  {
  MSG      msg;
  WNDCLASS window_class;

  if (!hPrevInstance)
    {
    window_class.style = CS_HREDRAW | CS_VREDRAW;
    window_class.lpfnWndProc = WndProc;
    window_class.cbClsExtra = window_class.cbWndExtra = 0;
    window_class.hInstance = _hInstance;
    window_class.hIcon = LoadIcon(_hInstance, "ICON_1");
    window_class.hCursor = LoadCursor(NULL, IDC_ARROW);
    window_class.hbrBackground = GetStockObject(WHITE_BRUSH);
    window_class.lpszMenuName = NULL;
    window_class.lpszClassName = program_name;
    RegisterClass(&window_class);
    BWCCGetVersion(); // make sure BWCC.DLL is loaded
    }
    
  main_hwnd = CreateWindow
    (
    program_name, program_name,
    WS_OVERLAPPEDWINDOW | WS_CLIPCHILDREN,
    CW_USEDEFAULT, CW_USEDEFAULT,
    CW_USEDEFAULT, CW_USEDEFAULT,
    NULL, NULL, _hInstance, NULL);

  ShowWindow(main_hwnd, nCmdShow);
  UpdateWindow(main_hwnd);

  while (GetMessage(&msg, NULL, 0, 0))
    {
    TranslateMessage(&msg);
    DispatchMessage(&msg);
    }

  return msg.wParam;
  }



